.. pyableton documentation master file, created by
   sphinx-quickstart on Mon Jan  8 12:32:35 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

PyAbleton's documentation
=====================================
PyAbleton is a Python library for parsing and working with Ableton Live files (.als). 
This library provides functionality to extract information from Ableton Live projects, making it easier to analyze, manipulate, and interact with Ableton Live sets programmatically.


Contents 
========

.. toctree::
   :maxdepth: 2
   
   getting_started
   classes/index
